@@ -223,9 +223,9 @@ comp.omega <- function(d, u, m=2,  pco=NULL, K=1){
     stop("Missing typicality matrix")
   if(is.null(u))
     stop("Memberships matrix contains no data")
-  if(class(u) == "data.frame")
+  if(is(u, "data.frame"))
     u <- as.matrix(u)
-  if(class(u) != "matrix")
+  if(!is(u, "matrix"))
     stop("Memberships data must be numeric data frame or matrix")
   if(any(is.na(u)))
     stop("Memberships data should not contain NA values")
@@ -235,9 +235,9 @@ comp.omega <- function(d, u, m=2,  pco=NULL, K=1){
     stop("Missing distance matrix")
   if(is.null(d))
     stop("Distance matrix contains no data")
-  if(class(d) == "data.frame")
+  if(is(d, "data.frame"))
     d <- as.matrix(d)
-  if(class(d) != "matrix")
+  if(!is(d,"matrix"))
     stop("Distance data must be numeric data frame or matrix")
   if(any(is.na(d)))
     stop("Distance data should not contain NA values")
